# Table of Contents

- [discovery-and-integrations](<./discovery-and-integrations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Discovery and Integrations](<./Discovery-and-Integrations.md>)
  - [Overview](<./Discovery-and-Integrations/Overview.md>)
  - [Setting Up Out-of-the-Box Integrations](<./Discovery-and-Integrations/Setting-Up-Out-of-the-Box-Integrations.md>)
  - [Sync Logs of Integrations](<./Discovery-and-Integrations/Sync-Logs-of-Integrations.md>)
  - [Discovery and Integrations](<./Discovery-and-Integrations/Discovery-and-Integrations.md>)
  - [Reference Catalog](<./Discovery-and-Integrations/Reference-Catalog.md>)
